Pooled

Struct Pooled 

pub struct Pooled<'a, T> { /* private fields */ }
A borrowed object from the pool - returns automatically when dropped.

Use take() if you need to keep the object instead of returning it to the pool.

Implementations

Source

impl<T> Pooled<'_, T>

pub fn take(self) -> T

Takes ownership of the inner value, preventing it from being returned to the pool.

Panics

Panics if the value has already been taken from this Pooled handle.