pub struct SectionFlags {
pub required: bool,
pub mmap_able: bool,
}Expand description
Flags for a section entry in the container directory.
Fields
required: boolBit 0: section is required (older binaries must refuse to open if unknown). When false, unknown section types can be safely skipped.
mmap_able: boolBit 1: section data can be mmap’d for zero-copy access.
Implementations