pub struct Duration { /* private fields */ }Expand description
An ISO 8601 duration with separate month, day, and nanosecond components.
The three components are kept separate because months have variable length and cannot be converted to days without a reference date. This means durations are only partially ordered.
Examples
use grafeo_common::types::Duration;
let d = Duration::parse("P1Y2M3DT4H5M6S").unwrap();
assert_eq!(d.months(), 14); // 1 year + 2 months
assert_eq!(d.days(), 3);
assert_eq!(d.to_string(), "P1Y2M3DT4H5M6S");Implementations
Sourceimpl Duration
impl Duration
Sourcepub const fn new(months: i64, days: i64, nanos: i64) -> Self
pub const fn new(months: i64, days: i64, nanos: i64) -> Self
Creates a duration from months, days, and nanoseconds.
Sourcepub const fn from_months(months: i64) -> Self
pub const fn from_months(months: i64) -> Self
Creates a duration from a number of months.
Sourcepub const fn from_nanos(nanos: i64) -> Self
pub const fn from_nanos(nanos: i64) -> Self
Creates a duration from nanoseconds.
Sourcepub const fn from_seconds(secs: i64) -> Self
pub const fn from_seconds(secs: i64) -> Self
Creates a duration from seconds.